stm8dce API documentation

# Package `stm8dce`

## Sub-modules

`stm8dce.asm_analysis`

  This module provides classes and functions helpful for analyzing SDCC generated STM8 assembly code.

`stm8dce.asm_matchers`

  This module provides functions to pattern match STM8 SDCC generated assembly code.

`stm8dce.asm_parser`

  This module provides a class to parse STM8 SDCC generated assembly files.

`stm8dce.debug`

  This module provides debug output functions.

`stm8dce.rel_analysis`

  This module provides classes and functions for analyzing .rel and .lib files

`stm8dce.rel_matchers`

  This module provides functions to pattern match STM8 SDCC generated .rel and .lib files. For more information on the STM8 .rel and .lib file formats, …

`stm8dce.rel_parser`

  This module provides functions to parse .rel and .lib files.

`stm8dce.settings`

  This module contains global settings for the STM8DCE tool